# Generated by Django 5.2.6 on 2025-09-24 04:56

import django_revision.revision_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_microbiology",
            "0016_alter_historicalmicrobiology_device_created_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="blood_culture_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_report",
            field=models.TextField(
                blank=True, default="", verbose_name="Histopathoplogy report"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="blood_culture_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="tissue_biopsy_report",
            field=models.TextField(
                blank=True, default="", verbose_name="Histopathoplogy report"
            ),
        ),
    ]
