# Generated by Django 5.2.6 on 2025-09-17 04:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_microbiology", "0013_alter_historicalmicrobiology_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_modified",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_modified",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Device modified"
            ),
        ),
    ]
